@@ -14,22 +14,28 @@ import time
 from .gitCommand import execute_git
 from .inquirer import questions
 
-init()
+init(autoreset=True)
 config_obj = ConfigParser()
+parser = config_obj.read(path.join(Path.home(), ".pyGinitconfig.ini"))
 
-# TODO : check remote repository if exist
+gh = Github(config_obj["auth"]["token"])
+
+# TODO : check remote repository is exist
 # TODO : add new command 'remote' to create (empty)-remote repository only
-# TODO : add configuration so user that contains 
+# TODO : add feature to add license
+# TODO : add option command so user can initiazlize with only one line
+# TODO : add configuration so user that contains
 #        customization or default value by user,e.g : change styles,set defaul value etc
 # TODO : add ssh
 
+
 @click.group()
-@click.version_option("0.2.1", help="Show version")
+@click.version_option("0.2.2", help="Show version")
 def pyginit():
     """pyGinit a simple cli automation tools
     to initalize both local and remote repository
 
-    version : 0.2.1
+    version : 0.2.2
     """
     pass
 
@@ -51,7 +57,7 @@ def add_gitignore(gitginore_template):
     add gitignore template if the parameter is not equal None
 
             parameters :
-                gitginore_template(str) : gitignore template name e.g python,javascript etc         
+                gitginore_template(str) : gitignore template name e.g python,javascript etc
     """
     gitginore_template = gitginore_template.rstrip("\n")  # remove trailing newline
     try:
@@ -59,11 +65,10 @@ def add_gitignore(gitginore_template):
             url = (
                 "https://raw.githubusercontent.com/github/gitignore/master/"
                 + gitginore_template.strip(" ")
-                + ".gitignore"
             )
             """ download gitignore template from github repository(yeah...repository github account itself) """
-            dowonload = requests.get(url)
-            open(".gitignore", "wb").write(dowonload.content)
+            download = requests.get(url)
+            open(".gitignore", "wb").write(download.content)
         elif gitginore_template == ".gitignore":
             open(".gitignore").close()
         else:
@@ -77,26 +82,44 @@ def add_gitignore(gitginore_template):
         exit()
 
 
-@pyginit.command()
-def init():
-    """ initialize local git repository and create remote github repository """
-    answers = prompt(questions, style=custom_style_2)
-    private = True if answers.get("repo_type") == "private" else False
-    parser = config_obj.read(path.join(Path.home(), ".pyGinitconfig.ini"))
-    url_check = "https://github.com/{username}/{repo_name}".format(
-        username=config_obj["auth"]["username"], repo_name=answers.get("repo_name")
-    )
+def check_git_exist():
+    """
+    check wether local git is exist or not
+    """
     if call(["git", "branch"], stderr=STDOUT, stdout=open(devnull, "w")) != 0:
         pass
     else:
         if call(["git", "branch"], stderr=STDOUT, stdout=open(devnull, "w")) != 0:
-            click.echo(
-                "Local repository already exists"
-            )
-        click.echo("Local repository already exists, pyGinit only accept directory without git")
+            click.echo("Local repository already exists")
+        click.echo(
+            "Local repository already exists, pyGinit only accept directory without git"
+        )
         exit()
+
+
+"""
+still under development
+def create_repo(repo_name:str,description:str,private:bool):
+    user = gh.get_user()
+    # create github repo
+    repo = user.create_repo(
+        repo_name,
+        description,
+        private,
+    )
+"""
+
+
+@pyginit.command()
+def init():
+    """initialize local git repository and create remote github repository"""
+    answers = prompt(questions, style=custom_style_2)
+    private = True if answers.get("repo_type") == "private" else False
+    parser = config_obj.read(path.join(Path.home(), ".pyGinitconfig.ini"))
+
     try:
-        # check both remote and local repository are exist
+        # check local repository are exist
+        check_git_exist()
         # if not program will continue
 
         """
@@ -109,20 +132,35 @@ def init():
         for now let's just use these code below
         """
 
+        try:
+            repo = gh.get_repo(
+                config_obj["auth"]["username"] + "/" + answers.get("repo_name")
+            )
+        except:
+            pass  # if repository not exist/get exception it means program can continue
+        else:
+            click.echo(
+                Fore.YELLOW
+                + Style.BRIGHT
+                + "Remote repository already exist at: "
+                + repo.clone_url()
+            )
+            click.echo(Fore.YELLOW + Style.BRIGHT + "Program stopped")
+            exit()
+
         """  
         main parts where remote repositorty are created 
         if exception happen(connection error,wrong inpu etc) repository(local and remote)
         is not created
-        """
         # add readme
+        """
         add_readme(
             answers.get("readme_confirm"),
             answers.get("repo_name"),
             answers.get("description"),
         )
-        add_gitignore(answers.get("gitginore_template"))# add gitignore
-        #github authorization
-        gh = Github(config_obj["auth"]["token"])
+        add_gitignore(answers.get("gitginore_template"))  # add gitignore
+        # github authorization
         user = gh.get_user()
         # create github repo
         repo = user.create_repo(
@@ -130,15 +168,14 @@ def init():
             description=answers.get("description"),
             private=private,
         )
-
-        """
-        """
+        # create_repo(answers.get("repo_name"), answers.get("description"), private)
 
     except KeyError:
         click.echo(
             Fore.RED
             + Style.BRIGHT
-            + "Error : github token not found,use set-auth command to set your token and username"
+            + "Error : github token not found,use set-auth command to set your token"
+            " and username"
         )
 
     #  two exception below are throw when some prompt are not filled or user abort the command
@@ -147,14 +184,14 @@ def init():
     except TypeError:
         exit()
 
-
     except BadCredentialsException:
         click.echo(
             Fore.RED
             + Style.BRIGHT
-            + "Error : authrization error. have you entered the correct token and username?"
+            + "Error : authrization error. have you entered the correct token and"
+            " username?"
         )
-    #? How to get github error message?
+    # ? How to get github error message?
     except GithubException as e:
         click.echo(Fore.RED + Style.BRIGHT + "Error when creating remote repository")
         raise e
@@ -184,13 +221,13 @@ def init():
         click.echo("pushing file to remote")
 
         # initialize local git and push it to remote
-        # if user cancel the pushing process, 
+        # if user cancel the pushing process,
         # only remote repository are created(empty repo)
         execute_git(
             config_obj["auth"]["username"],
             config_obj["auth"]["token"],
             answers.get("repo_name"),
-            answers.get("remote_name")
+            answers.get("remote_name"),
         )
         click.echo(Fore.GREEN + Style.BRIGHT + "Repository succesfully created 🎉🎉")
 
@@ -199,13 +236,17 @@ def init():
 @click.argument("token", metavar="<github_token>")
 @click.argument("username", metavar="<github_username>")
 def set_auth(token, username):
-    """ set your github token and username """
+    """set your github token and username"""
     try:
-        config_obj["auth"] = {
-            "token": token,
-            "username": username,
-        }
+        config_obj["auth"] = {"token": token, "username": username}
         with open(path.join(Path.home(), ".pyGinitconfig.ini"), "w") as conf:
             config_obj.write(conf)
     except Exception as e:
         print(e)
+
+
+"""
+@pyginit.command()
+def remote():
+    click.echo("create remote repository only")
+"""
